pygeodesy.auxilats.auxAngle.AuxAngle

Package pygeodesy :: Package auxilats :: Module auxAngle :: Class AuxAngle |
[frames] | no frames]

# Class AuxAngle

      object --+
               |
    named._Named --+
                   |
                  AuxAngle

Known Subclasses:
  - AuxBeta
  - , AuxChi
  - , auxLat.AuxLat
  - , AuxMu
  - , AuxPhi
  - , AuxTheta
  - , AuxXi

An accurate representation of angles

Instance Methods
__abs__(self) Return this angle's absolute value (AuxAngle). |
__add__(self, other) Return `self + other` as an AuxAngle. |
__bool__(self) Return `True` if this angle is non-zero. |
__eq__(self, other) Return `self == other` as `bool`. |
__float__(self) Return this angle's `tan` (`float`). |
__iadd__(self, other) Apply `self += other` to this angle. |
__init__(self, y_angle=0.0, x=1.0, aux=None, **name) New AuxAngle. |
__isub__(self, other) Apply `self -= other` to this angle. |
__ne__(self, other) Return `self != other` as `bool`. |
__neg__(self) Return a copy of this angle, negated. |
__pos__(self) Return this angle as-is, like `float.__pos__()`. |
__radd__(self, other) Return `other + self` as an AuxAngle. |
__rsub__(self, other) Return `other - self` as an AuxAngle. |
__str__(self) Default `str(self)`. |
__sub__(self, other) Return `self - other` as an AuxAngle. |
copyquadrant(self, other) Copy an `other` angle's quadrant into this angle (auxAngle). |
normal(self) Normalize this angle in-place. |
toBeta(self, rhumb) Short for `rhumb.auxDLat.convert(Aux.BETA, self, exact=rhumb.exact)` |
toChi(self, rhumb) Short for `rhumb.auxDLat.convert(Aux.CHI, self, exact=rhumb.exact)` |
toMu(self, rhumb) Short for `rhumb.auxDLat.convert(Aux.MU, self, exact=rhumb.exact)` |
toPhi(self, rhumb) Short for `rhumb.auxDLat.convert(Aux.PHI, self, exact=rhumb.exact)` |
Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Static Methods
fromDegrees(deg, **aux_name) Get an AuxAngle from degrees. |
fromLambertianDegrees(psi, **aux_name) Get an AuxAngle from Lambertian degrees. |
fromLambertianRadians(psi, **aux_name) Get an AuxAngle from Lambertian radians. |
fromRadians(rad, **aux_name) Get an AuxAngle from radians. |

Properties
| diff Get derivative `dtan(Eta) / dtan(Phi)` (`float` or `NAN`).
| iteration Get the iteration (`int` or `None`).
| normalized Get a normalized copy of this angle (AuxAngle).
| tan Get this angle's `tan` (`float`).
| toDegrees Get this angle as Degrees.
| toLambertianDegrees Get this angle's Lambertian in Degrees.
| toLambertianRadians Get this angle's Lambertian in Radians.
| toRadians Get this angle as Radians.
| x Get this angle's `x` (`float`).
| y Get this angle's `y` (`float`).
Inherited from `named._Named`: `classname`, `classnaming`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __add__ (self, other) (Addition operator) |
Return `self + other` as an AuxAngle. Arguments: `other` - An AuxAngle. Returns: The sum (AuxAngle). Raises: `TypeError` - Invalid `other`.

### __iadd__ (self, other) |
Apply `self += other` to this angle. Arguments: `other` - An AuxAngle. Returns: This angle, updated (AuxAngle). Raises: `TypeError` - Invalid `other`.

### __init__ (self, y_angle=0.0, x=1.0, aux=None, **name) (Constructor) |
New AuxAngle. Arguments: `y_angle` - The Y component (`scalar`, including `INF`, `NAN` and `NINF`) or a previous AuxAngle instance. `x` - The X component, required if `y_angle` is `scalar`, ignored otherwise. `aux` - Auxiliary kind (`Aux.KIND`), like `x`. `name` - Optional `name=NN` see (`str`). Raises: `AuxError` - Invalid `y_angle`, `x` or `aux`. Overrides: object.__init__

### __isub__ (self, other) |
Apply `self -= other` to this angle. Arguments: `other` - An AuxAngle. Returns: This instance, updated (AuxAngle). Raises: `TypeError` - Invalid `other` type.

### __radd__ (self, other) (Right-side addition operator) |
Return `other + self` as an AuxAngle. See Also: Method AuxAngle.__add__.

### __rsub__ (self, other) |
Return `other - self` as an AuxAngle. See Also: Method AuxAngle.__sub__.

### __str__ (self) (Informal representation operator) |
Default `str(self)`. Overrides: object.__str__ (inherited documentation)

### __sub__ (self, other) (Subtraction operator) |
Return `self - other` as an AuxAngle. Arguments: `other` - An AuxAngle. Returns: The difference (AuxAngle). Raises: `TypeError` - Invalid `other` type.

### normal (self) |
Normalize this angle in-place. Returns: This angle, normalized (AuxAngle).

Property Details

### diff Get derivative `dtan(Eta) / dtan(Phi)` (`float` or `NAN`). Get method: diff(self) - Get derivative `dtan(Eta) / dtan(Phi)` (`float` or `NAN`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### iteration Get the iteration (`int` or `None`). Get method: iteration(self) - Get the iteration (`int` or `None`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### normalized Get a normalized copy of this angle (AuxAngle). Get method: normalized(self) - Get a normalized copy of this angle (AuxAngle). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### tan Get this angle's `tan` (`float`). Get method: tan(self) - Get this angle's `tan` (`float`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### toDegrees Get this angle as Degrees. Get method: toDegrees(self) - Get this angle as Degrees. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### toLambertianDegrees Get this angle's Lambertian in Degrees. Get method: toLambertianDegrees(self) - Get this angle's Lambertian in Degrees. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### toLambertianRadians Get this angle's Lambertian in Radians. Get method: toLambertianRadians(self) - Get this angle's Lambertian in Radians. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### toRadians Get this angle as Radians. Get method: toRadians(self) - Get this angle as Radians. Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### x Get this angle's `x` (`float`). Get method: x(self) - Get this angle's `x` (`float`). Set method: x(self, x) - Set this angle's `x` (`float`). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### y Get this angle's `y` (`float`). Get method: y(self) - Get this angle's `y` (`float`). Set method: y(self, y) - Set this angle's `y` (`float`). Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.